==============================================
``psyclone.domain.lfric.lfric_arg_descriptor``
==============================================

.. automodule:: psyclone.domain.lfric.lfric_arg_descriptor

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.lfric.lfric_arg_descriptor


Classes
=======

- :py:class:`LFRicArgDescriptor`:
  This class captures the information specified in one of LFRic API argument


.. autoclass:: LFRicArgDescriptor
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: LFRicArgDescriptor
      :parts: 1
